==> tabular-data-gwt-service-2.2.0-20140625.141438-106-sources.jar: org/gcube/portlets/user/td/gwtservice/server/file/CSVFileUploadSession.java <==
package org.gcube.portlets.user.td.gwtservice.server.file;

import java.io.File;
import java.io.Serializable;

import org.gcube.portlets.user.td.gwtservice.shared.csv.CSVImportMonitor;
import org.gcube.portlets.user.td.gwtservice.shared.csv.CSVParserConfiguration;
import org.gcube.portlets.user.td.gwtservice.shared.file.FileUploadMonitor;
import org.gcube.portlets.user.td.gwtservice.shared.file.FileUploadState;

/**
 * 
 * @author "Giancarlo Panichi" 
 * <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
 *
 */
public class CSVFileUploadSession implements Serializable {
	
	private static final long serialVersionUID = -7906477664944910362L;
	
	protected String id;
	
	protected FileUploadState fileUploadState;
	
	protected File csvFile;
	protected String csvName;
	
	protected CSVParserConfiguration parserConfiguration;
	
	protected CSVImportMonitor csvImportMonitor;
	

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public FileUploadState getFileUploadState() {
		return fileUploadState;
	}

	public void setFileUploadState(FileUploadState fileUploadState) {
		this.fileUploadState = fileUploadState;
	}

	public File getCsvFile() {
		return csvFile;
	}

	public void setCsvFile(File csvFile) {
		this.csvFile = csvFile;
	}

	public String getCsvName() {
		return csvName;
	}

	public void setCsvName(String csvName) {
		this.csvName = csvName;
	}

	public CSVParserConfiguration getParserConfiguration() {
		return parserConfiguration;
	}

	public void setParserConfiguration(CSVParserConfiguration parserConfiguration) {
		this.parserConfiguration = parserConfiguration;
	}

	public CSVImportMonitor getCsvImportMonitor() {
		return csvImportMonitor;
	}

	public void setCsvImportMonitor(CSVImportMonitor csvImportMonitor) {
		this.csvImportMonitor = csvImportMonitor;
	}

	@Override
	public String toString() {
		return "CSVFileUploadSession [id=" + id + ", fileUploadState="
				+ fileUploadState + ", csvFile=" + csvFile + ", csvName="
				+ csvName + ", parserConfiguration=" + parserConfiguration
				+ ", csvImportMonitor=" + csvImportMonitor + "]";
	}

	
	
		
}

==> tabular-data-gwt-service-2.7.0-20150622.164805-157-sources.jar: org/gcube/portlets/user/td/gwtservice/server/file/CSVFileUploadSession.java <==
package org.gcube.portlets.user.td.gwtservice.server.file;

import java.io.File;
import java.io.Serializable;

import org.gcube.portlets.user.td.gwtservice.shared.csv.CSVParserConfiguration;
import org.gcube.portlets.user.td.gwtservice.shared.file.FileUploadState;

/**
 * 
 * @author "Giancarlo Panichi" 
 * <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
 *
 */
public class CSVFileUploadSession implements Serializable {
	
	private static final long serialVersionUID = -7906477664944910362L;
	
	protected String id;
	
	protected FileUploadState fileUploadState;
	
	protected File csvFile;
	protected String csvName;
	
	protected CSVParserConfiguration parserConfiguration;
	
	//protected CSVImportMonitor csvImportMonitor;
	

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public FileUploadState getFileUploadState() {
		return fileUploadState;
	}

	public void setFileUploadState(FileUploadState fileUploadState) {
		this.fileUploadState = fileUploadState;
	}

	public File getCsvFile() {
		return csvFile;
	}

	public void setCsvFile(File csvFile) {
		this.csvFile = csvFile;
	}

	public String getCsvName() {
		return csvName;
	}

	public void setCsvName(String csvName) {
		this.csvName = csvName;
	}

	public CSVParserConfiguration getParserConfiguration() {
		return parserConfiguration;
	}

	public void setParserConfiguration(CSVParserConfiguration parserConfiguration) {
		this.parserConfiguration = parserConfiguration;
	}

	@Override
	public String toString() {
		return "CSVFileUploadSession [id=" + id + ", fileUploadState="
				+ fileUploadState + ", csvFile=" + csvFile + ", csvName="
				+ csvName + ", parserConfiguration=" + parserConfiguration
				+ "]";
	}
	
		
}
